@@ -15,12 +15,18 @@ pub fn render_shortcuts(_app: &App, area: Rect, frame: &mut Frame<CrosstermBacke
         .border_type(tui::widgets::BorderType::Rounded)
         .border_style(Style::default().fg(Color::LightMagenta))
         .title_alignment(tui::layout::Alignment::Center)
-        .title(Span::styled("Shortcuts", Style::default().fg(Color::White)));
+        .title(Span::styled(
+            " Shortcuts ",
+            Style::default().fg(Color::White),
+        ));
 
     let text = vec![
-        Spans::from("'c' to alternate between configuration display mode"),
-        Spans::from("'g' to alternate between groups mode"),
-        Spans::from("'Enter' to SSH to your server"),
+        Spans::from("'Enter': Validate"),
+        Spans::from("'Tab': Change Group"),
+        Spans::from("'c': Configuration Display Mode"),
+        Spans::from("'PageUp/Down': Scroll Configuration"),
+        // Spans::from("'g' to alternate between groups mode"),
+        Spans::from("'q': Exit"),
     ];
 
     let paragraph = Paragraph::new(text)
